InMemoryManager class

Constructors

InMemoryManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getImage(PCacheImage key, {bool clearMemoryImg = false}) ImageStreamCompleter
Get the image
init({int maxInMemoryImages = Constants.INFINITE_IN_MEMORY_IMAGES}) → void
Initialize the the In-memory manager