PCacheImageService class

Paulonia cache image service for mobile

This class has all function to download, store and get the images.

Constructors

PCacheImageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAllImages() Future
getImage(String url, Duration retryDuration, Duration maxRetryDuration, bool enableCache, {bool clearCacheImage = false}) Future<Codec>
Get the image codec
init({String? proxy}) Future<void>
Initialize the service on mobile